aboutsummaryrefslogtreecommitdiffstats
path: root/graphql/connections/gen_identity.go
diff options
context:
space:
mode:
authorMichael Muré <batolettre@gmail.com>2020-02-09 02:56:37 +0100
committerGitHub <noreply@github.com>2020-02-09 02:56:37 +0100
commit3caffeef4d2ed25d4eb5d4bfd262f4fc3b92561f (patch)
tree40730a7ff92a420af65d9d2560a07d47a6a72174 /graphql/connections/gen_identity.go
parent9e1a987b4d94dc5c2115423ede5954d4faf1d342 (diff)
parent2af456f5e05f242d9e13049e038b9bd2d6dfc1cc (diff)
downloadgit-bug-3caffeef4d2ed25d4eb5d4bfd262f4fc3b92561f.tar.gz
Merge pull request #316 from MichaelMure/lazy-graphql
graphql: use the cache in priority for fast browsing in the WebUI
Diffstat (limited to 'graphql/connections/gen_identity.go')
-rw-r--r--graphql/connections/gen_identity.go11
1 files changed, 5 insertions, 6 deletions
diff --git a/graphql/connections/gen_identity.go b/graphql/connections/gen_identity.go
index b52b6f96..061e8936 100644
--- a/graphql/connections/gen_identity.go
+++ b/graphql/connections/gen_identity.go
@@ -8,23 +8,22 @@ import (
"fmt"
"github.com/MichaelMure/git-bug/graphql/models"
- "github.com/MichaelMure/git-bug/identity"
)
// IdentityInterfaceEdgeMaker define a function that take a identity.Interface and an offset and
// create an Edge.
-type IdentityEdgeMaker func(value identity.Interface, offset int) Edge
+type IdentityEdgeMaker func(value models.IdentityWrapper, offset int) Edge
// IdentityConMaker define a function that create a models.IdentityConnection
type IdentityConMaker func(
edges []*models.IdentityEdge,
- nodes []identity.Interface,
+ nodes []models.IdentityWrapper,
info *models.PageInfo,
totalCount int) (*models.IdentityConnection, error)
// IdentityCon will paginate a source according to the input of a relay connection
-func IdentityCon(source []identity.Interface, edgeMaker IdentityEdgeMaker, conMaker IdentityConMaker, input models.ConnectionInput) (*models.IdentityConnection, error) {
- var nodes []identity.Interface
+func IdentityCon(source []models.IdentityWrapper, edgeMaker IdentityEdgeMaker, conMaker IdentityConMaker, input models.ConnectionInput) (*models.IdentityConnection, error) {
+ var nodes []models.IdentityWrapper
var edges []*models.IdentityEdge
var cursors []string
var pageInfo = &models.PageInfo{}
@@ -8,23 +8,22 @@ import (
)
-// IdentityInterfaceEdgeMaker define a function that take a identity.Interface and an offset and
+// ModelsIdentityWrapperEdgeMaker define a function that take a models.IdentityWrapper and an offset and
// create an Edge.